import React, { useEffect, useState } from "react";

const CollectEmails = ({ showModal, onClose }) => {
  const [email, setEmail] = useState("");
  const [shouldShow, setShouldShow] = useState(false);
  const [justSubmitted, setJustSubmitted] = useState(false);

  // Check localStorage on mount
  useEffect(() => {
    const alreadySubscribed = localStorage.getItem("subscribed");
    if (!alreadySubscribed && showModal) {
      setShouldShow(true);
    }
  }, [showModal]);

  const handleSubmit = (e) => {
    e.preventDefault();
    if (!email) return;

    // Save subscription status and show fake success message
    localStorage.setItem("subscribed", "true");
    setJustSubmitted(true);

    // Close modal shortly after
    setTimeout(() => {
      setShouldShow(false);
      setJustSubmitted(false);
      onClose();
    }, 1500);

    // Fire API call in background
    fetch("/api/sendemail", {
      method: "POST",
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify({
        email,
        name: "DrawSketch Subscriber",
        subject: "Newsletter Subscription",
        message: `This user has subscribed to the DrawSketch newsletter: ${email}`,
      }),
    }).catch((err) => {
      console.error("Subscription API error:", err);
      // Optional: silently log or report error
    });
  };

  if (!shouldShow) return null;

  return (
    <div className="z-50 fixed top-0 left-0 right-0 bottom-0 bg-black bg-opacity-50 flex items-center justify-center">
      <div className="relative bg-white p-8 rounded-2xl shadow-2xl w-full max-w-md transition-all duration-300">
        <h2 className="text-3xl font-bold text-purple-700 mb-6 text-center">
          🎨 Get Updates from DrawSketch
        </h2>

        {!justSubmitted ? (
          <form
            onSubmit={handleSubmit}
            className="flex flex-col items-center space-y-4"
          >
            <input
              type="email"
              value={email}
              onChange={(e) => setEmail(e.target.value)}
              placeholder="Enter your email"
              required
              className="p-3 w-full border-2 border-purple-400 rounded-xl focus:outline-none focus:ring-2 focus:ring-purple-300"
            />
            <button
              type="submit"
              className="bg-purple-600 text-white py-3 px-6 w-full rounded-xl shadow-md hover:bg-purple-700 transition duration-200 focus:outline-none focus:ring-2 focus:ring-purple-300"
            >
              Subscribe
            </button>
          </form>
        ) : (
          <div className="text-center text-purple-600 text-lg font-medium">
            ✅ Thanks for subscribing! You’ll get updates soon.
          </div>
        )}
      </div>
    </div>
  );
};

export default CollectEmails;
